@@ -77,7 +77,7 @@ extensions.append('sphinx.ext.ifconfig')
 # -- Link to other Sphinx documentations
 extensions.append('sphinx.ext.intersphinx')
 
-intersphinx_mapping = {'python': ('http://docs.python.org/2.7', None)}
+intersphinx_mapping = {'python': ('https://docs.python.org/2.7', None)}
 
 # -- Keep track of :todo: items
 extensions.append('sphinx.ext.todo')
@@ -91,6 +91,11 @@ try:
 except ImportError:
     pass
 
+# -- Documentation coverage (`make apidoc-coverage`)
+extensions.append('sphinx.ext.coverage')
+
+coverage_skip_undoc_in_source = True
+
 
 # Add any paths that contain templates here, relative to this directory.
 #templates_path = ['utils/templates']
@@ -362,4 +367,4 @@ def setup(app):
     roles.register_canonical_role('extensionpoints', extensionpoints_role)
 
     # ifconfig variables
-    app.add_config_value('devel', '', True)
+    app.add_config_value('devel', True, '')
