@@ -15,7 +15,7 @@
 """Example macro."""
 
 revision = "$Rev: 12605 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.2-stable/sample-plugins/HelloWorld.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-1.2.2/sample-plugins/HelloWorld.py $"
 
 from trac.util.translation import cleandoc_
 from trac.wiki.macros import WikiMacroBase
