@@ -15,7 +15,7 @@
 """Inserts the current time (in seconds) into the wiki page."""
 
 revision = "$Rev: 14481 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.2-stable/sample-plugins/Timestamp.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-1.2.2/sample-plugins/Timestamp.py $"
 
 from datetime import datetime
 
