@@ -16,7 +16,7 @@ from trac.core import *
 from trac.perm import IPermissionPolicy, IPermissionRequestor
 
 revision = "$Rev: 12166 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.2-stable/sample-plugins/permissions/vulnerability_tickets.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-1.2.2/sample-plugins/permissions/vulnerability_tickets.py $"
 
 class SecurityTicketsPolicy(Component):
     """Prevent public access to security sensitive tickets.
