@@ -17,7 +17,7 @@ from trac.ticket.api import ITicketActionController
 from trac.perm import IPermissionRequestor
 
 revision = "$Rev: 13452 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.2-stable/sample-plugins/workflow/DeleteTicket.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-1.2.2/sample-plugins/workflow/DeleteTicket.py $"
 
 class DeleteTicketActionController(Component):
     """Provides the admin with a way to delete a ticket.
