@@ -21,7 +21,7 @@ from trac.ticket.model import Priority, Ticket
 #from trac.perm import IPermissionRequestor # (TODO)
 
 revision = "$Rev: 12166 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.2-stable/sample-plugins/workflow/VoteOperation.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-1.2.2/sample-plugins/workflow/VoteOperation.py $"
 
 class VoteOperation(Component):
     """Provides a simplistic vote feature.
