@@ -18,7 +18,6 @@ import difflib
 import inspect
 import os
 import re
-import shutil
 import sys
 import tempfile
 import unittest
@@ -54,7 +53,7 @@ from trac.admin.console import TracAdmin, TracAdminHelpMacro, _run
 from trac.config import ConfigSection, Option
 from trac.core import Component, ComponentMeta, implements
 from trac.env import Environment
-from trac.test import EnvironmentStub
+from trac.test import EnvironmentStub, rmtree
 from trac.util import create_file
 from trac.util.compat import close_fds
 from trac.util.datefmt import format_date, get_date_format_hint, \
@@ -1556,12 +1555,12 @@ class TracadminTestCase(TracAdminTestCaseBase):
 
     def test_changeset_add_invalid_repository(self):
         rv, output = self._execute('changeset added repos 123')
-        self.assertEqual(0, rv, output)
+        self.assertEqual(2, rv, output)
         self.assertExpectedResult(output)
 
     def test_changeset_modify_invalid_repository(self):
         rv, output = self._execute('changeset modified repos 123')
-        self.assertEqual(0, rv, output)
+        self.assertEqual(2, rv, output)
         self.assertExpectedResult(output)
 
 
@@ -1705,7 +1704,7 @@ class TracAdminInitenvTestCase(TracAdminTestCaseBase):
     def tearDown(self):
         if os.path.isfile(os.path.join(self.env_path, 'VERSION')):
             self._admin.env.shutdown()
-        shutil.rmtree(self.parent_dir)
+        rmtree(self.parent_dir)
 
     def test_config_argument(self):
         """Options contained in file specified by the --config argument
@@ -1771,6 +1770,42 @@ the_plugin.* = enabled
         })
 
 
+class TracAdminDeployTestCase(TracAdminTestCaseBase):
+    """Tests for the trac-admin deploy command."""
+
+    def setUp(self):
+        self.env = Environment(path=tempfile.mkdtemp(), create=True)
+        self._admin = TracAdmin(self.env.path)
+        self._admin.env_set('', self.env)
+
+    def tearDown(self):
+        self.env.shutdown()  # really closes the db connections
+        rmtree(self.env.path)
+
+    def test_deploy(self):
+        """Deploy into valid target directory."""
+        target = os.path.join(self.env.path, 'www')
+        htdocs_dir = os.path.join(target, 'htdocs')
+
+        rv, output = self._execute('deploy %s' % target)
+
+        self.assertEqual(0, rv, output)
+        self.assertExpectedResult(output)
+        self.assertTrue(os.path.exists(os.path.join(target, 'cgi-bin')))
+        self.assertTrue(os.path.exists(htdocs_dir))
+        self.assertTrue(os.path.exists(os.path.join(htdocs_dir, 'common')))
+        self.assertTrue(os.path.exists(os.path.join(htdocs_dir, 'site')))
+
+    def test_deploy_to_invalid_target_raises_error(self):
+        """Running deploy with target directory equal to or below the source
+        directory raises AdminCommandError.
+        """
+        rv, output = self._execute('deploy %s' % self.env.htdocs_dir)
+
+        self.assertEqual(2, rv, output)
+        self.assertExpectedResult(output)
+
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TracadminTestCase))
@@ -1782,6 +1817,7 @@ def test_suite():
         print("SKIP: trac.admin.tests.console.TracAdminComponentTestCase "
               "(__name__ is not trac.admin.tests.console)")
     suite.addTest(unittest.makeSuite(TracAdminInitenvTestCase))
+    suite.addTest(unittest.makeSuite(TracAdminDeployTestCase))
     return suite
 
 
