@@ -14,7 +14,6 @@
 
 import contextlib
 import os
-import shutil
 import tempfile
 import time
 import unittest
@@ -23,7 +22,7 @@ import trac.tests.compat
 from trac.config import *
 from trac.config import UnicodeConfigParser
 from trac.core import Component, ComponentMeta, Interface, implements
-from trac.test import Configuration, EnvironmentStub
+from trac.test import Configuration, EnvironmentStub, rmtree
 from trac.util import create_file, read_file
 from trac.util.compat import wait_for_file_mtime_change
 from trac.util.datefmt import time_now
@@ -59,7 +58,7 @@ class UnicodeParserTestCase(unittest.TestCase):
         self._read()
 
     def tearDown(self):
-        shutil.rmtree(self.tempdir)
+        rmtree(self.tempdir)
 
     def _write(self):
         with open(self.filename, 'w') as f:
@@ -282,9 +281,9 @@ class ConfigurationTestCase(unittest.TestCase):
 class IntegrationTestCase(BaseTestCase):
 
     def test_repr(self):
-        self.assertEquals('<Configuration None>', repr(Configuration(None)))
+        self.assertEqual('<Configuration None>', repr(Configuration(None)))
         config = self._read()
-        self.assertEquals("<Configuration %r>" % self.filename, repr(config))
+        self.assertEqual("<Configuration %r>" % self.filename, repr(config))
 
     def test_default(self):
         config = self._read()
@@ -469,16 +468,18 @@ class IntegrationTestCase(BaseTestCase):
         self.assertEqual(expected, config.getlist('a', 'option', '', sep='||'))
 
     def test_read_and_choice(self):
-        self._write(['[a]', 'option = 2', 'invalid = d',
+        self._write(['[a]', 'option = 2', 'invalid = d', 'case-insensitive = b',
                      u'[û]', u'èncoded = à'])
         config = self._read()
 
         class Foo(object):
-            # enclose in parentheses to avoid messages extraction
-            option = (ChoiceOption)('a', 'option', ['Item1', 2, '3'])
-            other = (ChoiceOption)('a', 'other', [1, 2, 3])
-            invalid = (ChoiceOption)('a', 'invalid', ['a', 'b', 'c'])
-            encoded = (ChoiceOption)('a', u'èncoded', [u'à', u'ć', u'ē'])
+            option = ChoiceOption('a', 'option', ['Item1', 2, '3'])
+            other = ChoiceOption('a', 'other', [1, 2, 3])
+            invalid = ChoiceOption('a', 'invalid', ['a', 'b', 'c'])
+            encoded = ChoiceOption('a', u'èncoded', [u'à', u'ć', u'ē'])
+            case_insensitive = ChoiceOption('a', 'case-insensitive',
+                                            ['A', 'B', 'C'],
+                                            case_sensitive=False)
 
             def __init__(self):
                 self.config = config
@@ -490,6 +491,7 @@ class IntegrationTestCase(BaseTestCase):
         self.assertEqual(u'à', foo.encoded)
         config.set('a', u'èncoded', u'ć')
         self.assertEqual(u'ć', foo.encoded)
+        self.assertEqual('B', foo.case_insensitive)
 
     def test_read_and_getextensionoption(self):
         self._write(['[a]', 'option = ImplA', 'invalid = ImplB'])
@@ -502,12 +504,12 @@ class IntegrationTestCase(BaseTestCase):
             implements(IDummy)
 
         class Foo(Component):
-            default1 = (ExtensionOption)('a', 'default1', IDummy)
-            default2 = (ExtensionOption)('a', 'default2', IDummy, 'ImplA')
-            default3 = (ExtensionOption)('a', 'default3', IDummy, 'ImplB')
-            option = (ExtensionOption)('a', 'option', IDummy)
-            option2 = (ExtensionOption)('a', 'option', IDummy, 'ImplB')
-            invalid = (ExtensionOption)('a', 'invalid', IDummy)
+            default1 = ExtensionOption('a', 'default1', IDummy)
+            default2 = ExtensionOption('a', 'default2', IDummy, 'ImplA')
+            default3 = ExtensionOption('a', 'default3', IDummy, 'ImplB')
+            option = ExtensionOption('a', 'option', IDummy)
+            option2 = ExtensionOption('a', 'option', IDummy, 'ImplB')
+            invalid = ExtensionOption('a', 'invalid', IDummy)
 
             def __init__(self):
                 self.config = config
@@ -541,16 +543,15 @@ class IntegrationTestCase(BaseTestCase):
             implements(IDummy)
 
         class Foo(Component):
-            # enclose in parentheses to avoid messages extraction
-            default1 = (OrderedExtensionsOption)('a', 'default1', IDummy,
-                                                 include_missing=False)
-            default2 = (OrderedExtensionsOption)('a', 'default2', IDummy)
-            default3 = (OrderedExtensionsOption)('a', 'default3', IDummy,
-                                                 'ImplB, ImplC',
-                                                 include_missing=False)
-            option = (OrderedExtensionsOption)('a', 'option', IDummy,
+            default1 = OrderedExtensionsOption('a', 'default1', IDummy,
                                                include_missing=False)
-            invalid = (OrderedExtensionsOption)('a', 'invalid', IDummy)
+            default2 = OrderedExtensionsOption('a', 'default2', IDummy)
+            default3 = OrderedExtensionsOption('a', 'default3', IDummy,
+                                               'ImplB, ImplC',
+                                               include_missing=False)
+            option = OrderedExtensionsOption('a', 'option', IDummy,
+                                             include_missing=False)
+            invalid = OrderedExtensionsOption('a', 'invalid', IDummy)
 
             def __init__(self):
                 self.config = config
@@ -718,8 +719,7 @@ class IntegrationTestCase(BaseTestCase):
         self.assertEqual(['a', 'b'], config.sections())
 
         class Foo(object):
-            # enclose in parentheses to avoid messages extraction
-            section_c = (ConfigSection)('c', 'Doc for c')
+            section_c = ConfigSection('c', 'Doc for c')
             option_c = Option('c', 'option', 'value')
 
         self.assertEqual(['a', 'b', 'c'], config.sections())
@@ -865,19 +865,18 @@ class IntegrationTestCase(BaseTestCase):
 
     def test_option_with_raw_default(self):
         class Foo(object):
-            # enclose in parentheses to avoid messages extraction
-            option_none = (Option)('a', 'none', None)
-            option_blah = (Option)('a', 'blah', u'Blàh!')
-            option_true = (BoolOption)('a', 'true', True)
-            option_false = (BoolOption)('a', 'false', False)
-            option_list = (ListOption)('a', 'list', ['#cc0', 4.2, 42L, 0, None,
-                                                     True, False, None],
-                                       sep='|', keep_empty=True)
-            option_list = (ListOption)('a', 'list-seps',
-                                       ['#cc0', 4.2, 42L, 0, None, True, False,
-                                        None],
-                                       sep=(',', '|'), keep_empty=True)
-            option_choice = (ChoiceOption)('a', 'choice', [-42, 42])
+            option_none = Option('a', 'none', None)
+            option_blah = Option('a', 'blah', u'Blàh!')
+            option_true = BoolOption('a', 'true', True)
+            option_false = BoolOption('a', 'false', False)
+            option_list1 = ListOption('a', 'list', ['#cc0', 4.2, 42L, 0, None,
+                                                    True, False, None],
+                                      sep='|', keep_empty=True)
+            option_list2 = ListOption('a', 'list-seps',
+                                      ['#cc0', 4.2, 42L, 0, None, True, False,
+                                       None],
+                                      sep=(',', '|'), keep_empty=True)
+            option_choice = ChoiceOption('a', 'choice', [-42, 42])
 
         config = self._read()
         config.set_defaults()
@@ -900,16 +899,15 @@ class IntegrationTestCase(BaseTestCase):
 
     def test_unicode_option_with_raw_default(self):
         class Foo(object):
-            # enclose in parentheses to avoid messages extraction
-            option_none = (Option)(u'résumé', u'nöné', None)
-            option_blah = (Option)(u'résumé', u'bláh', u'Blàh!')
-            option_true = (BoolOption)(u'résumé', u'trüé', True)
-            option_false = (BoolOption)(u'résumé', u'fálsé', False)
-            option_list = (ListOption)(u'résumé', u'liśt',
-                                       [u'#ccö', 4.2, 42L, 0, None, True,
+            option_none = Option(u'résumé', u'nöné', None)
+            option_blah = Option(u'résumé', u'bláh', u'Blàh!')
+            option_true = BoolOption(u'résumé', u'trüé', True)
+            option_false = BoolOption(u'résumé', u'fálsé', False)
+            option_list = ListOption(u'résumé', u'liśt',
+                                     [u'#ccö', 4.2, 42L, 0, None, True,
                                         False, None],
-                                       sep='|', keep_empty=True)
-            option_choice = (ChoiceOption)(u'résumé', u'chöicé', [-42, 42])
+                                     sep='|', keep_empty=True)
+            option_choice = ChoiceOption(u'résumé', u'chöicé', [-42, 42])
 
         config = self._read()
         config.set_defaults()
@@ -930,13 +928,12 @@ class IntegrationTestCase(BaseTestCase):
 
     def test_option_with_non_normal_default(self):
         class Foo(object):
-            # enclose in parentheses to avoid messages extraction
-            option_int_0 = (IntOption)('a', 'int-0', 0)
-            option_float_0 = (FloatOption)('a', 'float-0', 0)
-            option_bool_1 = (BoolOption)('a', 'bool-1', '1')
-            option_bool_0 = (BoolOption)('a', 'bool-0', '0')
-            option_bool_yes = (BoolOption)('a', 'bool-yes', 'yes')
-            option_bool_no = (BoolOption)('a', 'bool-no', 'no')
+            option_int_0 = IntOption('a', 'int-0', 0)
+            option_float_0 = FloatOption('a', 'float-0', 0)
+            option_bool_1 = BoolOption('a', 'bool-1', '1')
+            option_bool_0 = BoolOption('a', 'bool-0', '0')
+            option_bool_yes = BoolOption('a', 'bool-yes', 'yes')
+            option_bool_no = BoolOption('a', 'bool-no', 'no')
 
         expected = [
             '# -*- coding: utf-8 -*-\n',
@@ -1129,11 +1126,11 @@ class OptionDocTestCase(BaseTestCase):
 
     def test_config_section(self):
         class Dummy(object):
-            section_a = (ConfigSection)('a', 'Doc for a')
-            section_b = (ConfigSection)(
+            section_a = ConfigSection('a', 'Doc for a')
+            section_b = ConfigSection(
                 'b', 'Doc for [%(page)s@%(version)d b]',
                 doc_args={'page': 'WikiStart', 'version': 42})
-            section_c = (ConfigSection)('c', '')
+            section_c = ConfigSection('c', '')
 
         self.assertEqual('Doc for a', Dummy.section_a.__doc__)
         self.assertEqual(None, Dummy.section_a.doc_args)
@@ -1152,29 +1149,29 @@ class OptionDocTestCase(BaseTestCase):
             pass
         class Dummy(Component):
             implements(IDummy)
-            opt_nodoc = (Option)('a', 'option_nodoc', 'default')
-            opt = (Option)(
+            opt_nodoc = Option('a', 'option_nodoc', 'default')
+            opt = Option(
                 'a', 'option', 'default',
                 doc='Doc for %(name)s', doc_args={'name': 'opt'})
-            bool_opt = (BoolOption)(
+            bool_opt = BoolOption(
                 'a', 'bool_opt', 'false',
                 doc='Doc for %(name)s', doc_args={'name': 'bool_opt'})
-            int_opt = (IntOption)(
+            int_opt = IntOption(
                 'a', 'int_opt', '42',
                 doc='Doc for %(name)s', doc_args={'name': 'int_opt'})
-            float_opt = (IntOption)(
+            float_opt = IntOption(
                 'a', 'float_opt', '4.2',
                 doc='Doc for %(name)s', doc_args={'name': 'float_opt'})
-            list_opt = (ListOption)(
+            list_opt = ListOption(
                 'a', 'list_opt', 'foo,bar,baz',
                 doc='Doc for %(name)s', doc_args={'name': 'list_opt'})
-            path_opt = (PathOption)(
+            path_opt = PathOption(
                 'a', 'path_opt', 'trac.ini',
                 doc='Doc for %(name)s', doc_args={'name': 'path_opt'})
-            ext_opt = (ExtensionOption)(
+            ext_opt = ExtensionOption(
                 'a', 'ext_opt', IDummy, 'Dummy',
                 doc='Doc for %(name)s', doc_args={'name': 'ext_opt'})
-            ordered_ext_opt = (OrderedExtensionsOption)(
+            ordered_ext_opt = OrderedExtensionsOption(
                 'a', 'ordered_ext_opt', IDummy, 'Dummy,Dummy',
                 doc='Doc for %(name)s', doc_args={'name': 'ordered_ext_opt'})
 
