@@ -28,95 +28,6 @@ from trac.web.api import HTTPBadRequest, RequestDone
 from trac.web.chrome import Chrome
 
 
-class ReportTestCase(unittest.TestCase):
-
-    def setUp(self):
-        self.env = EnvironmentStub(default_data=True)
-
-    def tearDown(self):
-        self.env.reset_db()
-
-    def test_repr(self):
-        Report(self.env).insert()
-        self.assertEqual("<Report 1>", repr(Report(self.env, 1)))
-        self.assertEqual("<Report None>", repr(Report(self.env)))
-
-    def test_create(self):
-        report = Report(self.env, 4)
-        self.assertTrue(report.exists)
-        self.assertEqual(4, report.id)
-        self.assertEqual("Accepted, Active Tickets by Owner", report.title)
-        self.assertEqual("List accepted tickets, group by ticket owner, "
-                         "sorted by priority.\n", report.description)
-        self.assertIn("SELECT p.value AS __color__,", report.query)
-
-    def test_create_exists_false(self):
-        self.assertRaises(ResourceNotFound, Report, self.env, 9)
-
-    def test_insert(self):
-        report = Report(self.env)
-        report.title = "The report"
-        report.description = "The description"
-        report.query = "SELECT 1"
-        report.insert()
-        self.assertEqual(9, report.id)
-
-    def test_insert_existing_report(self):
-        report = Report(self.env, 1)
-        self.assertRaises(AssertionError, report.insert)
-
-    def test_delete(self):
-        report = Report(self.env, 1)
-        report.delete()
-        self.assertFalse(report.exists)
-        self.assertRaises(ResourceNotFound, Report, self.env, 1)
-
-    def test_delete_not_exists(self):
-        report = Report(self.env)
-        self.assertRaises(AssertionError, report.delete)
-
-    def test_update(self):
-        report = Report(self.env, 1)
-        title, description, query = \
-            report.title, report.description, report.query
-        report.title = "The report"
-        report.description = "The description"
-        report.query = "SELECT 1"
-        report.update()
-
-        report = Report(self.env, 1)
-        self.assertNotEqual(title, report.title)
-        self.assertNotEqual(description, report.description)
-        self.assertNotEqual(query, report.query)
-        self.assertEqual("The report", report.title)
-        self.assertEqual("The description", report.description)
-        self.assertEqual("SELECT 1", report.query)
-
-    def test_select(self):
-        reports = list(Report.select(self.env))
-        self.assertEqual(1, reports[0].id)
-        self.assertEqual('Active Tickets', reports[0].title)
-        self.assertEqual(" * List all active tickets by priority.\n"
-                         " * Color each row based on priority.\n",
-                         reports[0].description)
-        self.assertIn("SELECT p.value AS __color__", reports[0].query)
-        self.assertEqual(8, len(reports))
-        self.assertEqual(1, reports[0].id)
-        self.assertEqual(8, reports[-1].id)
-
-    def test_select_sort_desc(self):
-        reports = list(Report.select(self.env, asc=False))
-        self.assertEqual(8, len(reports))
-        self.assertEqual(8, reports[0].id)
-        self.assertEqual(1, reports[-1].id)
-
-    def test_select_order_by_title(self):
-        reports = list(Report.select(self.env, sort='title'))
-        self.assertEqual(8, len(reports))
-        self.assertEqual(4, reports[0].id)
-        self.assertEqual(7, reports[-1].id)
-
-
 class ReportModuleTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -185,7 +96,9 @@ class ReportModuleTestCase(unittest.TestCase):
                          req.headers_sent['Location'])
 
     def test_update_report(self):
-        Report(self.env).insert()
+        report = Report(self.env)
+        report.query = "SELECT 1"
+        report.insert()
         req = MockRequest(self.env, method='POST', args={
             'action': 'edit',
             'id': '1',
@@ -202,7 +115,9 @@ class ReportModuleTestCase(unittest.TestCase):
         self.assertIn("Your changes have been saved.", req.chrome['notices'])
 
     def test_update_report_cancel(self):
-        Report(self.env).insert()
+        report = Report(self.env)
+        report.query = "SELECT 1"
+        report.insert()
         req = MockRequest(self.env, method='POST', args={
             'action': 'edit',
             'cancel': True,
@@ -349,6 +264,53 @@ class ReportModuleTestCase(unittest.TestCase):
         self.assertEqual([], missing_args)
         self.assertEqual(None, limit_offset)
 
+    def test_with_no_sql(self):
+        with self.env.db_transaction as db:
+            cursor = db.cursor()
+            cursor.execute("""INSERT INTO report (title,query,description)
+                              VALUES ('#12709', '', '')""")
+            id_ = db.get_last_id(cursor, 'report')
+        req = MockRequest(self.env, path_info='/report/%d' % id_)
+        self.assertTrue(self.report_module.match_request(req))
+        data = self.report_module.process_request(req)[1]
+        self.assertEqual('Report failed: Report {%d} has no SQL query.' % id_,
+                         data['message'])
+
+    def test_value_error_from_get_var_args(self):
+        req = MockRequest(self.env, path_info='/report/1')
+        def get_var_args(req):
+            raise ValueError('<error>')
+        self.report_module.get_var_args = get_var_args
+        self.assertTrue(self.report_module.match_request(req))
+        data = self.report_module.process_request(req)[1]
+        self.assertEqual('Report failed: <error>', data['message'])
+
+    def test_title_and_description_with_sub_vars(self):
+        with self.env.db_transaction as db:
+            cursor = db.cursor()
+            cursor.execute(
+                """INSERT INTO report (title,query,description)
+                   VALUES (%s,%s,%s)""",
+                ('Tickets on $M for $USER',
+                 'SELECT * FROM ticket WHERE milestone=$M AND owner=$USER',
+                 'Show tickets on $M for $USER'))
+            id_ = db.get_last_id(cursor, 'report')
+            for milestone in ('milestone1', 'milestone2'):
+                ticket = Ticket(self.env)
+                ticket.populate({'status': 'new', 'summary': 'Test 1',
+                                 'owner': 'joe', 'milestone': milestone})
+                ticket.insert()
+        req = MockRequest(self.env, path_info='/report/%d' % id_,
+                          authname='joe', args={'M': 'milestone2'})
+        self.assertTrue(self.report_module.match_request(req))
+        data = self.report_module.process_request(req)[1]
+        self.assertEqual('{%d} Tickets on milestone2 for joe' % id_,
+                         data['title'])
+        self.assertEqual('Show tickets on milestone2 for joe',
+                         data['description'])
+        self.assertIsNone(data['message'])
+        self.assertEqual(1, data['numrows'])
+
 
 class ExecuteReportTestCase(unittest.TestCase):
 
@@ -885,7 +847,6 @@ class NavContribReportModuleDisabledTestCase(NavigationContributorTestCase):
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite(trac.ticket.report))
-    suite.addTest(unittest.makeSuite(ReportTestCase))
     suite.addTest(unittest.makeSuite(ReportModuleTestCase))
     suite.addTest(unittest.makeSuite(ExecuteReportTestCase))
     suite.addTest(unittest.makeSuite(NavContribReportModuleEnabledTestCase))
