@@ -17,8 +17,7 @@ import unittest
 from datetime import datetime
 
 import trac.tests.compat
-from trac.test import EnvironmentStub
-from trac.tests.compat import rmtree
+from trac.test import EnvironmentStub, rmtree
 from trac.util import create_file
 from trac.versioncontrol.api import Changeset, DbRepositoryProvider, \
                                     RepositoryManager
@@ -404,7 +403,7 @@ class UnicodeNameTestCase(unittest.TestCase, GitCommandMixin):
             rev = storage.head()
             with storage.get_historian('HEAD', path) as historian:
                 hrev = storage.last_change('HEAD', path, historian)
-                self.assertEquals(rev, hrev)
+                self.assertEqual(rev, hrev)
 
         validate(paths[0], 'true')
         validate(paths[0], 'false')
